<?php
/**
 * The header for our theme.
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 * @package styledstore
 */

?>
<!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
<meta charset="<?php bloginfo( 'charset' ); ?>">
<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1, user-scalable=no">
<link rel="profile" href="http://gmpg.org/xfn/11">
<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">
<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
<!-- add scroll top feature -->
<?php do_action( 'styledstore_move_to_top' ); ?>
<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'styled-store' ); ?></a>
<header id="header">
	<div class="row">
		<div class="header col-xs-12 col-md-12">
			<div class="container">
				<div class="row">
				<?php
					/**
					 * @author StyledThemes
					 * @action_hook header_top_bar_social_links
					 * @uses social media links with icon
					 * @package styledstore-function
					*/

					do_action( 'styledstore_header_top_bar_social_links' ); ?>

					<?php if ( has_custom_logo() ) {
						styledstore_the_custom_logo();
					} else { ?>
							<div class="logo sameheight col-xs-8 col-sm-4">
								<div class="site-title">
									<a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a>
								</div>
								<div class="site-desc">
									<?php echo esc_html( get_bloginfo( 'description' ) ); ?>
								</div>
							</div>
					<?php } ?>
						
					<div class="navigation-menu sameheight col-xs-4 col-sm-8">
						<input id="main-menu-state" type="checkbox" />
						<label class="main-menu-btn" for="main-menu-state">
							<span class="main-menu-btn-icon"></span>
						</label>
						<?php
							$styledstore_primary_nav = array(
								'theme_location'  => 'primary',
								'container'       => false,
								'menu_class'      => 'sm',
								'menu_id'			=> 'main-menu',
								'fallback_cb'       => 'wp_page_menu'
							);
							wp_nav_menu( $styledstore_primary_nav );
						?>
					</div>
					<!-- mobile menu -->

				</div>
			</div>
		</div>
	</div>
</header>

<?php if ( has_header_image() && is_front_page() ) : ?>
	<div class="custom-header-image">
		<a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home">
			<img src="<?php header_image(); ?>" height="<?php echo esc_attr( get_custom_header()->height ); ?>" width="<?php echo esc_attr( get_custom_header()->width ); ?>" alt="<?php esc_attr_e( 'custom header image', 'styled-store' ); ?>" />
		</a>	
	</div>
<?php endif;
