<?php
/**
 * styledstore Theme Customizer.
 * @description This file build option inside customizer menu options
 * @package styledstore
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */

function styledstore_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector' => '.site-title a',
			'container_inclusive' => false,
			'render_callback' => 'styledstore_customize_partial_blogname',
		) );
		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector' => '.site-desc',
			'container_inclusive' => false,
			'render_callback' => 'styledstore_customize_partial_blogdescription',
		) );
	}

	/*
    =================================================
    Basic Setting
    =================================================
    */

	$wp_customize->add_section( 'basic_settings', array(
		'title'          => __( 'Basic Settings', 'styled-store' ),
		'priority'       => 40,
	) );

	// Setting for blog layout
	$wp_customize->add_setting( 'blog_layout', array(
		'default' => 'blogright',
		'sanitize_callback' => 'styledstore_sanitize_bloglayout',
	) );
	// Control for blog layout	
	$wp_customize->add_control( 'blog_layout', array(
		'label'   => __( 'Blog Layout', 'styled-store' ),
		'section' => 'basic_settings',
		'priority' => 2,
		'type'    => 'radio',
			'choices' => array(
				'blogright' => __( 'Blog with Right Sidebar', 'styled-store' ),
				'blogleft' => __( 'Blog with Left Sidebar', 'styled-store' ),
				'blogwide' => __( 'Blog Full Width &amp; no Sidebars', 'styled-store' ),
			),
	));

	/*
    =================================================
    Move to top setting
    =================================================
    */

    $wp_customize->add_setting( 'styledstore_movetotop', array(
		'default'        => '0',
		'sanitize_callback' => 'styledstore_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'styledstore_movetotop', array(
		'settings' => 'movetotop',
		'label'    => __( 'Enable Move To Top', 'styled-store' ),
		'section'  => 'basic_settings',		
		'type'     => 'checkbox',
		'priority' => 5,
	) );


	//hide author meta information
    $wp_customize->add_setting( 'styledstore_blog_tax', array(
		'sanitize_callback' => 'styledstore_sanitize_checkbox',
	));

	$wp_customize->add_control( 'styledstore_blog_tax', array(
        'type' => 'checkbox',
        'label'    => __( 'Hide Blog Taxonomy Section', 'styled-store' ),
        'section' => 'basic_settings',
		'priority' => 6,
    ) );
	
	
	/*
    =================================================
    Social Networking setting
    =================================================
    */

    $wp_customize->add_section( 'social_networking', array(
		'title'          => __( 'Social Networking', 'styled-store' ),
		'priority'       => 50,
	) );


	
// Setting for hiding the social bar	
	$wp_customize->add_setting( 'styledstore_show_social_icon', array(
		'sanitize_callback' => 'styledstore_sanitize_checkbox',
	));

	
	// Control for hiding the social bar	
	$wp_customize->add_control( 'styledstore_show_social_icon', array(
        'label' => __( 'Show Social Bar', 'styled-store' ),
		'type' => 'checkbox',
		'section' => 'social_networking',
		'priority' => 1,
    ) );

	// Setting group for Facebook
	$wp_customize->add_setting( 'facebook_uid', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'facebook_uid', array(
		'settings' => 'facebook_uid',
		'label'    => __( 'Facebook', 'styled-store' ),
		'section'  => 'social_networking',
		'type'     => 'url',
		'priority' => 1,
	) );

	// Setting group for skype
	$wp_customize->add_setting( 'skype_uid', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'skype_uid', array(
		'label'    => __( 'Skype', 'styled-store' ),
		'section'  => 'social_networking',
		'type'     => 'url',
		'priority' => 2,
	) );

	// Setting group for Twitter
	$wp_customize->add_setting( 'twitter_uid', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'twitter_uid', array(
		'label'    => __( 'Twitter', 'styled-store' ),
		'section'  => 'social_networking',
		'type'     => 'url',
		'priority' => 3,
	) );

	// Setting group for Twitter
	$wp_customize->add_setting( 'rss_uid', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'rss_uid', array(
		'label'    => __( 'RSS', 'styled-store' ),
		'section'  => 'social_networking',
		'type'     => 'url',
		'priority' => 3,
	) );

    /*
    =================================================
    Footer Setting
    =================================================
    */

    $wp_customize->add_panel( 'styledstore_footer', array(
		'title'          => __( 'Footer Setting', 'styled-store' ),
		'priority'       => 60,
	) );

	$wp_customize->add_section( 'styledstore_payment_gateway', array(
		'title'          => __( 'Payment Support', 'styled-store' ),
		'priority'       => 1,
		'panel'			=> 'styledstore_footer'
	) );
	
	/*

*/


	// Setting group for a Visa
	 $wp_customize->add_setting( 'styledstore_support_payment_visa', array(
		'sanitize_callback' => 'styledstore_sanitize_upload',
    ));
	 
    $wp_customize->add_control( new WP_Customize_Image_Control($wp_customize, 'styledstore_support_payment_visa', array(
        'label'    => __('Image 1', 'styled-store'),
        'section'  => 'styledstore_payment_gateway',
		'priority' => 1,
    )));
	
	// Setting group for a master card
	 $wp_customize->add_setting( 'styledstore_support_payment_mastercard', array(
		'sanitize_callback' => 'styledstore_sanitize_upload',
    ));
	
    $wp_customize->add_control( new WP_Customize_Image_Control($wp_customize, 'styledstore_support_payment_mastercard', array(
        'label'    => __( 'Image 2', 'styled-store'),
        'section'  => 'styledstore_payment_gateway',
		'priority' => 1,
    )));

    // Setting group for a master card
	 $wp_customize->add_setting( 'styledstore_support_payment_paypal', array(
		'sanitize_callback' => 'styledstore_sanitize_upload',
    ));
	
    $wp_customize->add_control( new WP_Customize_Image_Control($wp_customize, 'styledstore_support_payment_paypal', array(
        'label'    => __( 'Image 3', 'styled-store'),
        'section'  => 'styledstore_payment_gateway',
		'priority' => 1,
    )));

    // Setting group for a amazon
	 $wp_customize->add_setting( 'styledstore_support_payment_amazon', array(
		'sanitize_callback' => 'styledstore_sanitize_upload',
    ));
	
    $wp_customize->add_control( new WP_Customize_Image_Control($wp_customize, 'styledstore_support_payment_amazon', array(
        'label'    => __( 'Image 4', 'styled-store'),
        'section'  => 'styledstore_payment_gateway',
		'priority' => 1,
    )));
    // Setting group for a amazon
	 $wp_customize->add_setting( 'styledstore_support_payment_am', array(
		'sanitize_callback' => 'styledstore_sanitize_upload',
    ));
	
    $wp_customize->add_control( new WP_Customize_Image_Control($wp_customize, 'styledstore_support_payment_am', array(
        'label'    => __('Image 5', 'styled-store'),
        'section'  => 'styledstore_payment_gateway',
		'priority' => 1,
    )));

    //copy right notice
    $wp_customize->add_section( 'styledstore_footercopy', array(
		'title'          => __( 'Copyright Text', 'styled-store' ),
		'priority'       => 2,
		'panel'			=> 'styledstore_footer'
	) );

	// Setting for hiding the footer text	
	$wp_customize->add_setting( 'styledstore_show_footer_text', array(
		'defaul' => '',
		'sanitize_callback' => 'styledstore_sanitize_checkbox',
	));


	// Control for hiding the footer text	
	$wp_customize->add_control( 'styledstore_show_footer_text', array(
        'label' => __( 'Hide Copyright Text', 'styled-store' ),
		'type' => 'checkbox',
		'section' => 'styledstore_footercopy',
		'priority' => 1,
    ) );

} //end of styledstore_customize_register customizer 
add_action( 'customize_register', 'styledstore_customize_register' );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function styledstore_customize_preview_js() {
	wp_enqueue_script( 'styledstore_customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'styledstore_customize_preview_js' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @since Styled Store 1.0
 * @see styledstore_customize_register()
 *
 * @return void
 */
function styledstore_customize_partial_blogname() {

	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @since Styled Store 1.0
 * @see styledstore_customize_register()
 *
 * @return void
 */
function styledstore_customize_partial_blogdescription() {

	bloginfo( 'description' );
}

/**
 * Sanitize radio checkbox
 * @since Styled Store 1.0
 * @see styledstore_customize_register()
 *
 * @return void
 */
function styledstore_sanitize_bloglayout( $input ) {

	$valid = array(
			'blogright' => __( 'Blog with Right Sidebar', 'styled-store' ),
			'blogleft' => __( 'Blog with Left Sidebar', 'styled-store' ),
			'blogwide' => __( 'Blog Full Width &amp; no Sidebars', 'styled-store' ),
	);

	if ( array_key_exists( $input, $valid ) ) {
		return $input;
	} else {
		return '';
	}
}


/**
 * adds sanitization callback function : checkbox
 * @package Styledstore 
*/
function styledstore_sanitize_checkbox( $input ) {

if ( $input == 1 ) {
	    return 1;
	} else {
	    return '';
	}
}


/**
 * adds sanitization callback function : Image sanitization callback example.
 * @package Styledstore 
 * @version 1.0
*/
function styledstore_sanitize_upload( $image, $setting ) {
		/*
		 * Array of valid image file types.
		 *
		 * The array includes image mime types that are included in wp_get_mime_types()
		*/
    $mimes = array(
        'jpg|jpeg|jpe' => 'image/jpeg',
        'gif'          => 'image/gif',
        'png'          => 'image/png',
        'bmp'          => 'image/bmp',
        'tif|tiff'     => 'image/tiff',
        'ico'          => 'image/x-icon'
    );
		// Return an array with file extension and mime_type.
    $file = wp_check_filetype( $image, $mimes );
		// If $image has a valid mime_type, return it; otherwise, return the default.
    return ( $file['ext'] ? $image : $setting->default );
}

/**
 * adds sanitization callback function : TEXT
 * @package Styledstore 
 * @version 1.0
*/
function styledstore_sanitize_text( $input ) {

	return wp_kses_post( force_balance_tags( $input ) );
}