<?php
/**
 * File Name: styledstore-function
 * @package styledstore
 * @author StyledThemes
 * @since version since 1.0
 * @uses contain functions to extend features
*/

/**
 * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
 * @param array $args Configuration arguments.
 * @return array
 */
function styledstore_page_menu_args( $args ) {
	
	$args[ 'show_home' ] = true;
	$args[ 'container' ] = 'ul';
	$args[ 'menu_class' ] = 'sm sm-mint';
	$args[ 'menu_id' ]	= 'main-menu';
    $args['depth'] = 1;
	return $args;
}

add_filter( 'wp_page_menu_args', 'styledstore_page_menu_args' );

if ( ! function_exists( 'styledstore_the_custom_logo' ) ) :

/**
 * Displays the optional custom logo.
 * Does nothing if the custom logo is not available.
 * @since StyledStore
 */

function styledstore_the_custom_logo() {
	if ( function_exists( 'the_custom_logo' ) ) {
		the_custom_logo();
	}
}
endif;

if ( ! function_exists( 'styledstore_social_links' ) ) :
/**
 * @author StyledThemes 
 * @action_hook header_top_bar_social_links
 * @uses social media links with icon
*/

function styledstore_social_links() { 

	if( get_theme_mod( 'styledstore_show_social_icon' ) != '' ) { ?>
		<div class="social-icons ">
			<?php if( get_theme_mod( 'facebook_uid') ) { ?>
				<li class="social-icon facebook">
					<a href="<?php echo esc_url( get_theme_mod( 'facebook_uid') ); ?>">
						<i class="fa fa-facebook" aria-hidden="true"></i>
					</a>
				</li>
			<?php }
			if( get_theme_mod( 'skype_uid' ) ) { ?> 
				<li class="social-icon skype">
					<a href="skype:<?php echo get_theme_mod( 'skype_uid' );?>?call">
						<i class="fa fa-skype" aria-hidden="true"></i>
					</a>
				</li>
			<?php }
			if( get_theme_mod( 'twitter_uid' ) ) { ?> 
				<li class="social-icon twitter">
					<a href="<?php echo esc_url( get_theme_mod( 'twitter_uid' ) ); ?>">
						<i class="fa fa-twitter" aria-hidden="true"></i>
					</a>
				</li>
			<?php }
			if( get_theme_mod( 'rss_uid' ) ) { ?> 
				<li class="social-icon rss">
					<a href="<?php echo esc_url( get_theme_mod( 'rss_uid' ) ); ?>">
						<i class="fa fa-rss" aria-hidden="true"></i>
					</a>
				</li>
			<?php } 	
			//add extra social icon links 
			do_action( 'styledstore_add_social_icon' ); 
			?>
		</div>
	<?php }
}
endif;

add_action( 'styledstore_header_top_bar_social_links', 'styledstore_social_links', 10 );


if ( ! function_exists( 'styledstore_the_post_thumbnail' ) ) :
/**
 * @package Styledstore 
 * @author StyledThemes 
 * @since version 1.0
 * @return  post featured image
*/
function styledstore_the_post_thumbnail() {

	if ( post_password_required() || is_attachment() || ! has_post_thumbnail() ) {
		return;
	}

	if( is_singular() ) : ?>

		<div class="post-thumbnail">
			<?php if( is_single() && get_theme_mod( 'styledstore_hide_featured' ) == '' ) { ?>
				<a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true">
				<?php 
					the_post_thumbnail( 'styledstoreblog-image', array( 'alt' => the_title_attribute( 'echo=0' ), 'class' => 'post-featured-image' ) );
				echo '</a>';
				} elseif( is_page() && get_theme_mod( 'styledstore_hide_featured_page' ) == '' ) { ?>
					<a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true">
						<?php the_post_thumbnail( 'styledstoreblog-image', array( 'alt' => the_title_attribute( 'echo=0' ), 'class' => 'page-featured-image' ) );
					echo '</a>';
				} else {
					return;
				}	?>
			
		</div><!-- .post-thumbnail -->

		<?php else : 
				if( get_theme_mod( 'blog_layout' ) == 'blogwide') { ?>
					<a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true">
						<?php the_post_thumbnail( 'styledstore-blog-fulwidth', array( 'alt' => the_title_attribute( 'echo=0' ), 'class' => "blog-featured-image" ) ); ?>
					</a>
				<?php } else { ?>
						<a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true">
							<?php the_post_thumbnail( 'styledstoreblog-image', array( 'alt' => the_title_attribute( 'echo=0' ), 'class' => "blog-featured-image" ) ); ?>
						</a>

				<?php }	

		endif; // End is_singular()

}
endif;

if ( ! function_exists( 'styeldstore_design_comment_form')) :
/**
 * make custom changes on comment form
 *
 * Create your own styledstore_categorized_blog() function to override in a child theme.
 *
 * @since Styld Store 1.0
 *
 * @return customize comment form
 */
function styeldstore_design_comment_form($fields) {

	$commenter = wp_get_current_commenter();
	$req = get_option( 'require_name_email' );
	$aria_req = ( $req ? " aria-required='true'" : '' );

	$fields =  array(

	'author' =>
	    '<div classs="row">
	    	<div class="col-md-4 col-xs-12" id="styledstore-disable-padding">
			    <p class="comment-form-author"><label for="author">' . esc_html__( 'Name', 'styled-store' ) . '</label> ' .
			    ( $req ? '<span class="required">*</span>' : '' ) .
			    '<input id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) .
			    '" size="30"' . $aria_req . ' />
			    </p>
	    	</div>',

	'email' =>
	    '<div class="col-md-4 col-xs-12">
		    <p class="comment-form-email"><label for="email">' . esc_html__( 'Email', 'styled-store' ) . '</label> ' .
		    ( $req ? '<span class="required">*</span>' : '' ) .
		    '<input id="email" name="email" type="text" value="' . esc_attr(  $commenter['comment_author_email'] ) .
		    '" size="30"' . $aria_req . ' />
		    </p>
		</div>',

	'url' =>
	    '<div class="col-md-4 col-xs-12">
		    <p class="comment-form-url"><label for="url">' . esc_html__( 'Website', 'styled-store' ) . '</label>' .
		    '<input id="url" name="url" type="text" value="' . esc_attr( $commenter['comment_author_url'] ) .
		    '" size="30" />
		    </p>
		</div>
	    </div>',
);
	return $fields;
	

}
add_filter( 'comment_form_default_fields', 'styeldstore_design_comment_form' );
endif;

if ( ! function_exists( 'styledstore_comment_field_to_bottom')) :
/**
 * make text form below other form fields
 *
 * Create your own styledstore_comment_field_to_bottom() function to override in a child theme.
 *
 * @since Styld Store 1.0
 *
 * @return customize comment form
 */
function styledstore_comment_field_to_bottom( $fields ) {

	$comment_field = $fields['comment'];
	unset( $fields['comment'] );
	$fields['comment'] = $comment_field;
	return $fields;
}
add_filter( 'comment_form_fields', 'styledstore_comment_field_to_bottom' );
endif;


if ( ! function_exists( 'styledstore_change_comment_args') ) :
/**
 * change default arguments on comment form
 *
 * Create your own styledstore_change_comment_args() function to override in a child theme using styledstore_change_comment_args 
 * hook
 * @since Styld Store 1.0
 *
 * @return customize comment form
 */

function styledstore_change_comment_args($args) {

	$commenter = wp_get_current_commenter();
	$req = get_option( 'require_name_email' );
	$aria_req = ( $req ? " aria-required='true'" : '' );
	$required_text = '';

	$args = array(
		'title_reply' => esc_html__( 'Leave a Reply', 'styled-store' ),
		'class_submit' => 'styledstore-submit',
		'comment_notes_before' => '<p class="comment-notes">' .esc_html__( 'Your email address will not be published.', 'styled-store' ) . ( $req ? $required_text : '' ) . '</p>',
		'label_submit' => esc_html__( 'SUBMIT', 'styled-store' )
		);
	return $args;


}
endif;
add_filter( 'styledstore_change_comment_argument', 'styledstore_change_comment_args', 10, 1 );



if ( ! function_exists( 'styledstore_paging_nav' ) ) :
/**
 * Create pagination of posts
 *
 * Create your own styledstore_paging_nav() function to override in a child theme
 * hook
 * @since Styld Store 1.0
 *
 * @return pagination
 */

function styledstore_paging_nav() {
	
	global $wp_query;
    if ( $wp_query->max_num_pages > 1 ) { ?>
        <nav role="navigation" id="styledstore-navigation">
			<h1 class="screen-reader-text"><?php esc_html_e( 'Post navigation', 'styled-store' ); ?></h1>
                <div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Older posts', 'styled-store' ) ); ?></div>
                <div class="nav-next"><?php previous_posts_link( __( 'Newer posts <span class="meta-nav">&rarr;</span>', 'styled-store' ) ); ?></div>
        </nav><!-- #nav -->
	<?php
	}
}
endif;

/**
*@package Styled Store
*@since  version 2.5.0
*@description add move to top featured
*/

function styledstore_move_to_top_fnc() {

  $move_to_top_check = get_theme_mod('styledstore_movetotop' );
    if ($move_to_top_check == 1) { ?>
      <div class="styledstore_move_to_top"> 
        <i class="fa fa-arrow-up"></i>
      </div>  
    <?php }
}
add_action('styledstore_move_to_top', 'styledstore_move_to_top_fnc');

/**
*@package Styled Store
*@description add read more tag text
*/

add_filter( 'the_content_more_link', 'styledstore_modify_read_more_link' );

function styledstore_modify_read_more_link() {

	return '<div class="more-link">
			<a href="'.esc_url( get_permalink() ).'">' . esc_html__( 'READ MORE', 'styled-store' ) . '</a>
		</div>';
}

if ( ! function_exists( 'styledstore_payment_links' ) ) :
	/**
	 * @author StyledThemes 
	 * @action_hook header_top_bar_social_links
	 *  * Create your own styledstore_payment_links() function to override in a child theme.
	 * @uses social media links with icon
	*/
	function styledstore_payment_links() { ?>

		<div class="st-icons-block">
			<div class="container">
				<?php if( get_theme_mod( 'styledstore_support_payment_visa') ) { ?>
					<span class="footer-icon">
					<img src="<?php echo esc_url( get_theme_mod( 'styledstore_support_payment_visa' ) ); ?>">
					</span>
				<?php }

				if( get_theme_mod( 'styledstore_support_payment_mastercard' ) ) { ?>
					<span class="footer-icon">
						<img src="<?php echo esc_url( get_theme_mod( 'styledstore_support_payment_mastercard' ) ); ?>">
					</span>
				<?php } 
			 
				if( get_theme_mod( 'styledstore_support_payment_paypal') ) { ?>		
					<span class="footer-icon">
						<img src="<?php echo esc_url( get_theme_mod( 'styledstore_support_payment_paypal' ) ); ?>">
					</span>
				<?php }	

				if( get_theme_mod( 'styledstore_support_payment_amazon') ) { ?>	
				<span class="footer-icon">
					<img src="<?php echo esc_url( get_theme_mod( 'styledstore_support_payment_amazon' ) ); ?>">
				</span>
				<?php }
				
				if( get_theme_mod( 'styledstore_support_payment_am') ) { ?>	
					<span class="footer-icon">
						<img src="<?php echo esc_url( get_theme_mod( 'styledstore_support_payment_am' ) ); ?>">
					</span>
				<?php }
				/*Make use of styledstore-add-paymentgate action hooks to add payment links */ 	
				do_action( 'styledstore_add_paymentgate_way' ); ?>
			</div>
		</div>	

	<?php }
endif;
add_action( 'styledstore_add_payment_links', 'styledstore_payment_links' );

/**
 * @author StyledThemes 
 * @return true /false
 * @uses check for woocomerce plugin
 * @version 1.0
*/
function styledstore_check_woocommerce_activation() {

	return in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) );
}


add_action( 'styledstore_post_loop', 'styledstore_post_content_loop', 10 );

if ( ! function_exists( 'styledstore_post_content_loop' ) ) :
	/**
	 * @author StyledThemes 
	 * @action_hook styledstore_post_loop
	 * @return post loop on blog page
	 * @uses show number of post
	 * @version 1.0
	*/
	function styledstore_post_content_loop() { ?>

		<main id="main" class="site-main" role="main">
			<?php if ( have_posts() ) :
				while( have_posts() ) : the_post();
					/*
					 * If you want to override this in a child theme, then include a file
					 * called content-___.php (where ___ is the Post Format name) and that will be used instead.
					 */
					get_template_part( 'template-parts/content' );
			    	// End the loop.
				endwhile;
				//create pagination
				styledstore_paging_nav();
				// If no content, include the "No posts found" template.
			else :
				get_template_part( 'template-parts/content', 'none' );
			endif; ?>
		</main><!-- #main .site-main -->
<?php }
endif;

